==> exo-clouddrive-1.6.0-source-release.zip: exo-clouddrive-1.6.0/connectors/cmis/webapp/src/main/java/org/exoplatform/clouddrive/cmis/portlet/package-info.java <==
/*
 * Copyright (C) 2003-2015 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
/**
 * CMIS connector login portlet.
 */
@Application
@Portlet(name = "CMISLoginPortlet")
@Bindings({ @Binding(value = RepositoryService.class), @Binding(value = SessionProviderService.class),
    @Binding(value = NodeHierarchyCreator.class), @Binding(value = CloudDriveService.class),
    @Binding(value = CodeAuthentication.class) })
package org.exoplatform.clouddrive.cmis.portlet;

import org.exoplatform.clouddrive.CloudDriveService;
import org.exoplatform.clouddrive.cmis.login.CodeAuthentication;
import org.exoplatform.services.jcr.RepositoryService;
import org.exoplatform.services.jcr.ext.app.SessionProviderService;
import org.exoplatform.services.jcr.ext.hierarchy.NodeHierarchyCreator;

import juzu.Application;
import juzu.plugin.binding.Binding;
import juzu.plugin.binding.Bindings;
import juzu.plugin.portlet.Portlet;

==> exo-clouddrive-2.0.0-source-release.zip: exo-clouddrive-2.0.0/connectors/cmis/webapp/src/main/java/org/exoplatform/clouddrive/cmis/portlet/package-info.java <==
/*
 * Copyright (C) 2003-2015 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
/**
 * CMIS connector login portlet.
 */
@Application
@Portlet(name = "CMISLoginPortlet")
@Bindings({ @Binding(value = RepositoryService.class), @Binding(value = SessionProviderService.class),
    @Binding(value = NodeHierarchyCreator.class), @Binding(value = CloudDriveService.class),
    @Binding(value = CodeAuthentication.class) })
package org.exoplatform.clouddrive.cmis.portlet;

import org.exoplatform.services.cms.clouddrives.CloudDriveService;
import org.exoplatform.clouddrive.cmis.login.CodeAuthentication;
import org.exoplatform.services.jcr.RepositoryService;
import org.exoplatform.services.jcr.ext.app.SessionProviderService;
import org.exoplatform.services.jcr.ext.hierarchy.NodeHierarchyCreator;

import juzu.Application;
import juzu.plugin.binding.Binding;
import juzu.plugin.binding.Bindings;
import juzu.plugin.portlet.Portlet;
